import request from '@/utils/request'
// 查询派单记录列表
export function exportOrderResult(query) {
  return request({
    url: '/yiqing/orderLog/exportOrderResult',
    method: 'get',
    params: query
  })
}

// 查询派单记录列表
export function listOrderLog(query) {
  return request({
    url: '/yiqing/orderLog/list',
    method: 'get',
    params: query
  })
}

// 查询派单记录详细
export function getOrderLog(id) {
  return request({
    url: '/yiqing/orderLog/' + id,
    method: 'get'
  })
}

// 新增派单记录
export function addOrderLog(data) {
  return request({
    url: '/yiqing/orderLog',
    method: 'post',
    data: data
  })
}

// 修改派单记录
export function updateOrderLog(data) {
  return request({
    url: '/yiqing/orderLog',
    method: 'put',
    data: data
  })
}

// 删除派单记录
export function delOrderLog(id) {
  return request({
    url: '/yiqing/orderLog/' + id,
    method: 'delete'
  })
}

// 导出派单记录
export function exportOrderLog(query) {
  return request({
    url: '/yiqing/orderLog/export',
    method: 'get',
    params: query
  })
}
