<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch">
      <el-form-item label="操作日期" prop="dateline">
        <el-date-picker clearable size="small"
                        v-model="queryParams.dateline"
                        type="date"
                        value-format="yyyy-MM-dd"
                        placeholder="选择操作日期">
        </el-date-picker>
      </el-form-item>
      <el-form-item label="派单日期" prop="ordersTime">
        <el-date-picker clearable size="small"
                        v-model="queryParams.ordersTime"
                        type="date"
                        value-format="yyyy-MM-dd"
                        placeholder="选择派单日期">
        </el-date-picker>
      </el-form-item>
      <el-form-item label="天数" prop="days">
        <el-input
          v-model="queryParams.days"
          placeholder="请输入天数"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="核酸结果" prop="rnaResult">
        <el-select v-model="queryParams.rnaResult" placeholder="请选择核酸结果" clearable size="small">
          <el-option v-for="(i,index) in rnaResultData" :key="index" :label="i.label"
                     :value="i.id"/>
        </el-select>
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['yiqing:orderLog:add']"
        >新增
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['yiqing:orderLog:edit']"
        >修改
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['yiqing:orderLog:remove']"
        >删除
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          :loading="exportLoading"
          @click="handleExport"
          v-hasPermi="['yiqing:orderLog:export']"
        >导出
        </el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="orderLogList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center"/>
      <el-table-column label="操作日期" align="center" prop="dateline" width="180">
        <template slot-scope="scope">
          <span>{{ parseTime(scope.row.dateline, '{y}-{m}-{d}') }}</span>
        </template>
      </el-table-column>
      <el-table-column label="派单日期" align="center" prop="ordersTime" width="180">
        <template slot-scope="scope">
          <span>{{ parseTime(scope.row.ordersTime, '{y}-{m}-{d}') }}</span>
        </template>
      </el-table-column>
      <el-table-column label="天数" align="center" prop="days"/>
      <el-table-column label="核酸结果" align="center" prop="rnsResult"/>
      <el-table-column label="备注" align="center" prop="remark"/>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-download"
            @click="doExportOrderResult(scope.row)"
          >导出派单结果
          </el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['yiqing:orderLog:edit']"
          >修改
          </el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['yiqing:orderLog:remove']"
          >删除
          </el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改派单记录对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="600px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules">
        <el-form-item label="操作日期" prop="dateline">
          <el-date-picker clearable size="small"
                          v-model="form.dateline"
                          type="date"
                          value-format="yyyy-MM-dd"
                          placeholder="选择操作日期">
          </el-date-picker>
        </el-form-item>
        <el-form-item label="派单日期" prop="ordersTime">
          <el-date-picker clearable size="small"
                          v-model="form.ordersTime"
                          type="date"
                          value-format="yyyy-MM-dd"
                          placeholder="选择派单日期">
          </el-date-picker>
        </el-form-item>
        <el-form-item label="天数" prop="days">
          <el-input v-model="form.days" placeholder="请输入天数"/>
        </el-form-item>
        <el-form-item label="核酸结果" prop="rnsResult">
          <el-select v-model="form.rnaResult" placeholder="请选择核酸结果" clearable size="small">
            <el-option v-for="(i,index) in rnaResultData" :key="index" :label="i.label"
                       :value="i.id"/>
          </el-select>
        </el-form-item>
        <el-form-item label="备注" prop="remark">
          <el-input v-model="form.remark" type="textarea" placeholder="请输入内容"/>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import {
  addOrderLog,
  delOrderLog,
  exportOrderLog,
  exportOrderResult,
  getOrderLog,
  listOrderLog,
  updateOrderLog
} from '@/api/yiqing/orderLog'

export default {
  name: 'OrderLog',
  data() {
    return {
      rnaResultData: [
        {
          'id': '阴性',
          'label': '阴性'
        }, {
          'id': '阳性',
          'label': '阳性'
        }, {
          'id': '应测未测',
          'label': '应测未测'
        }
      ],
      // 遮罩层
      loading: true,
      // 导出遮罩层
      exportLoading: false,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 派单记录表格数据
      orderLogList: [],
      // 弹出层标题
      title: '',
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        dateline: null,
        ordersTime: null,
        days: null,
        rnsResult: null
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {}
    }
  },
  created() {
    this.getList()
  },
  methods: {
    /** 导出派单结果 */
    doExportOrderResult(row) {
      const queryParams = this.queryParams
      this.$modal.confirm('是否导出派单结果数据？').then(() => {
        this.exportLoading = true
        return exportOrderResult(row)
      }).then(response => {
        this.$download.name(response.msg)
        this.exportLoading = false
      }).catch(() => {
      })
    },
    /** 查询派单记录列表 */
    getList() {
      this.loading = true
      listOrderLog(this.queryParams).then(response => {
        this.orderLogList = response.rows
        this.total = response.total
        this.loading = false
      })
    },
    // 取消按钮
    cancel() {
      this.open = false
      this.reset()
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        dateline: null,
        ordersTime: null,
        days: null,
        rnsResult: null,
        isDelete: null,
        createBy: null,
        createTime: null,
        updateBy: null,
        updateTime: null,
        remark: null
      }
      this.resetForm('form')
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1
      this.getList()
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm('queryForm')
      this.handleQuery()
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length !== 1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset()
      this.open = true
      this.title = '添加派单记录'
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset()
      const id = row.id || this.ids
      getOrderLog(id).then(response => {
        this.form = response.data
        this.open = true
        this.title = '修改派单记录'
      })
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs['form'].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateOrderLog(this.form).then(() => {
              this.$modal.msgSuccess('修改成功')
              this.open = false
              this.getList()
            })
          } else {
            addOrderLog(this.form).then(() => {
              this.$modal.msgSuccess('新增成功')
              this.open = false
              this.getList()
            })
          }
        }
      })
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids
      this.$modal.confirm('是否确认删除派单记录编号为"' + ids + '"的数据项？').then(function() {
        return delOrderLog(ids)
      }).then(() => {
        this.getList()
        this.$modal.msgSuccess('删除成功')
      }).catch(() => {
      })
    },
    /** 导出按钮操作 */
    handleExport() {
      const queryParams = this.queryParams
      this.$modal.confirm('是否确认导出所有派单记录数据项？').then(() => {
        this.exportLoading = true
        return exportOrderLog(queryParams)
      }).then(response => {
        this.$download.name(response.msg)
        this.exportLoading = false
      }).catch(() => {
      })
    }
  }
}
</script>
